# Generated by Django 2.1.5 on 2019-07-22 01:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('smithy', '0002_auto_20190317_1052_squashed_0008_auto_20190317_1213'),
    ]

    operations = [
        migrations.AlterField(
            model_name='request',
            name='body',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='requestrecord',
            name='raw_request',
            field=models.TextField(),
        ),
    ]



# Generated by Django 2.1.5 on 2019-07-22 01:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('smithy', '0003_auto_20190721_2004'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bodyparameter',
            name='value',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='cookie',
            name='value',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='header',
            name='value',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='queryparameter',
            name='value',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='variable',
            name='value',
            field=models.TextField(blank=True),
        ),
    ]
